==> 3.5.12-core.tar: kdesdk/kbabel/kbabeldict/modules/poauxiliary/poauxiliary.h <==
/* ****************************************************************************
  This file is part of KBabel

  Copyright (C) 2000 by Matthias Kiefer
                            <matthias.kiefer@gmx.de>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the Qt library by Trolltech AS, Norway (or with modified versions
  of Qt that use the same license as Qt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  Qt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.

**************************************************************************** */

#ifndef POAUXILIARY_H
#define POAUXILIARY_H

#include "searchengine.h"

#include <tqguardedptr.h>
#include <tqdict.h>
class TQTimer;

namespace KBabel
{
    class Catalog;
}

class AuxiliaryPreferencesWidget;

class PoAuxiliary : public SearchEngine
{
    Q_OBJECT

public:
    PoAuxiliary(TQObject *parent=0, const char *name=0);
    virtual ~PoAuxiliary();

    virtual bool isReady() const;

    virtual TQString translate(const TQString& text, uint pluralForm);

    virtual bool isSearching() const;

    virtual void saveSettings(KConfigBase *config);
    virtual void readSettings(KConfigBase *config);

    virtual PrefWidget *preferencesWidget(TQWidget *parent);

    virtual const KAboutData *about() const;

    virtual TQString name() const;
    
    virtual TQString id() const;

    virtual TQString lastError();

    virtual bool usesRichTextResults();

public slots:
    virtual bool startSearch(const TQString& text, unsigned int pluralForm
	, const SearchFilter*filter);
    virtual bool startSearchInTranslation(const TQString& text);
    
    virtual void stopSearch();

    virtual void setEditedFile(const TQString&);
    virtual void setEditedPackage(const TQString&);
    virtual void setLanguageCode(const TQString&);
        

protected slots:
    /** reads the current settings from the preferences dialog */
    void applySettings();
    
    /** sets the current settings in the preferences dialog */
    void restoreSettings();

    void loadAuxiliary();
    
private:
    TQGuardedPtr<AuxiliaryPreferencesWidget> prefWidget;
    KBabel::Catalog *catalog;
    TQString auxPackage;
    TQString auxTranslator;
    TQString auxURL;

    TQString url;
    bool ignoreFuzzy;

    TQString editedFile;
    TQString package;
    TQString langCode;

    bool error;
    TQString errorMsg;

    bool stop;
    bool active;
    bool loading;
    bool initialized;

    TQTimer *loadTimer;

    struct Entry
    {
        TQString orig;
        TQString translation;
        TQString comment;
        bool fuzzy;
    };

    TQDict<Entry> msgidDict;
    TQDict<Entry> msgstrDict;
};

#endif

==> 3.5.13-core.tar: kdesdk/kbabel/kbabeldict/modules/poauxiliary/poauxiliary.h <==
/* ****************************************************************************
  This file is part of KBabel

  Copyright (C) 2000 by Matthias Kiefer
                            <matthias.kiefer@gmx.de>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  In addition, as a special exception, the copyright holders give
  permission to link the code of this program with any edition of
  the TQt library by Trolltech AS, Norway (or with modified versions
  of TQt that use the same license as TQt), and distribute linked
  combinations including the two.  You must obey the GNU General
  Public License in all respects for all of the code used other than
  TQt. If you modify this file, you may extend this exception to
  your version of the file, but you are not obligated to do so.  If
  you do not wish to do so, delete this exception statement from
  your version.

**************************************************************************** */

#ifndef POAUXILIARY_H
#define POAUXILIARY_H

#include "searchengine.h"

#include <tqguardedptr.h>
#include <tqdict.h>
class TQTimer;

namespace KBabel
{
    class Catalog;
}

class AuxiliaryPreferencesWidget;

class PoAuxiliary : public SearchEngine
{
    Q_OBJECT
  TQ_OBJECT

public:
    PoAuxiliary(TQObject *parent=0, const char *name=0);
    virtual ~PoAuxiliary();

    virtual bool isReady() const;

    virtual TQString translate(const TQString& text, uint pluralForm);

    virtual bool isSearching() const;

    virtual void saveSettings(KConfigBase *config);
    virtual void readSettings(KConfigBase *config);

    virtual PrefWidget *preferencesWidget(TQWidget *parent);

    virtual const KAboutData *about() const;

    virtual TQString name() const;
    
    virtual TQString id() const;

    virtual TQString lastError();

    virtual bool usesRichTextResults();

public slots:
    virtual bool startSearch(const TQString& text, unsigned int pluralForm
	, const SearchFilter*filter);
    virtual bool startSearchInTranslation(const TQString& text);
    
    virtual void stopSearch();

    virtual void setEditedFile(const TQString&);
    virtual void setEditedPackage(const TQString&);
    virtual void setLanguageCode(const TQString&);
        

protected slots:
    /** reads the current settings from the preferences dialog */
    void applySettings();
    
    /** sets the current settings in the preferences dialog */
    void restoreSettings();

    void loadAuxiliary();
    
private:
    TQGuardedPtr<AuxiliaryPreferencesWidget> prefWidget;
    KBabel::Catalog *catalog;
    TQString auxPackage;
    TQString auxTranslator;
    TQString auxURL;

    TQString url;
    bool ignoreFuzzy;

    TQString editedFile;
    TQString package;
    TQString langCode;

    bool error;
    TQString errorMsg;

    bool stop;
    bool active;
    bool loading;
    bool initialized;

    TQTimer *loadTimer;

    struct Entry
    {
        TQString orig;
        TQString translation;
        TQString comment;
        bool fuzzy;
    };

    TQDict<Entry> msgidDict;
    TQDict<Entry> msgstrDict;
};

#endif
